Package: spData
Title: Datasets for Spatial Analysis
Version: 2.3.4
Authors@R: c(person("Roger", "Bivand", role = "aut", email="Roger.Bivand@nhh.no", comment = c(ORCID = "0000-0003-2392-6140")),
    person("Jakub", "Nowosad", role = c("aut", "cre"), email="nowosad.jakub@gmail.com", comment = c(ORCID = "0000-0002-1057-3721")),
    person("Robin", "Lovelace", role = "aut", comment = c(ORCID = "0000-0001-5679-6536")),
    person("Angelos", "Mimis", role = "ctb"),
    person("Mark", "Monmonier", role = "ctb", comment = "author of the state.vbm dataset"), 
    person("Greg", "Snow", role = "ctb", comment = "author of the state.vbm dataset")
    )
Description: Diverse spatial datasets for demonstrating, benchmarking and teaching spatial data analysis. 
    It includes R data of class sf (defined by the package 'sf'), Spatial ('sp'), and nb ('spdep').
    Unlike other spatial data packages such as 'rnaturalearth' and 'maps', 
    it also contains data stored in a range of file formats including GeoJSON and GeoPackage, but from version 2.3.4, no longer ESRI Shapefile - use GeoPackage instead. 
    Some of the datasets are designed to illustrate specific analysis techniques.
    cycle_hire() and cycle_hire_osm(), for example, is designed to illustrate point pattern analysis techniques.
Depends: R (>= 3.3.0)
Imports: sp
Suggests: foreign, sf (>= 0.9-1), spDataLarge (>= 0.4.0), spdep,
        spatialreg
License: CC0
RoxygenNote: 7.3.2
LazyData: true
URL: https://jakubnowosad.com/spData/
BugReports: https://github.com/Nowosad/spData/issues
Additional_repositories: https://jakubnowosad.com/drat
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-01-07 17:30:43 UTC; jn
Author: Roger Bivand [aut] (<https://orcid.org/0000-0003-2392-6140>),
  Jakub Nowosad [aut, cre] (<https://orcid.org/0000-0002-1057-3721>),
  Robin Lovelace [aut] (<https://orcid.org/0000-0001-5679-6536>),
  Angelos Mimis [ctb],
  Mark Monmonier [ctb] (author of the state.vbm dataset),
  Greg Snow [ctb] (author of the state.vbm dataset)
Maintainer: Jakub Nowosad <nowosad.jakub@gmail.com>
Repository: CRAN
Date/Publication: 2025-01-08 12:40:02 UTC
Built: R 4.4.0; ; 2026-07-18 02:15:34 UTC; unix
