Package: spData
Title: Datasets for Spatial Analysis
Version: 0.3.3
Authors@R: c(person("Roger", "Bivand", role = "aut", email="Roger.Bivand@nhh.no", comment = c(ORCID = "0000-0003-2392-6140")),
    person("Jakub", "Nowosad", role = c("aut", "cre"), email="nowosad.jakub@gmail.com", comment = c(ORCID = "0000-0002-1057-3721")),
    person("Robin", "Lovelace", role = "aut", comment = c(ORCID = "0000-0001-5679-6536")),
    person("Mark", "Monmonier", role = "ctb", comment = "author of the state.vbm dataset"), 
    person("Greg", "Snow", role = "ctb", comment = "author of the state.vbm dataset")
    )
Description: Diverse spatial datasets for demonstrating, benchmarking and teaching spatial data analysis. 
    It includes R data of class sf (defined by the package 'sf'), Spatial ('sp'), and nb ('spdep').
    Unlike other spatial data packages such as 'rnaturalearth' and 'maps', 
    it also contains data stored in a range of file formats including GeoJSON, ESRI Shapefile and GeoPackage. 
    Some of the datasets are designed to illustrate specific analysis techniques.
    cycle_hire() and cycle_hire_osm(), for example, is designed to illustrate point pattern analysis techniques.
Depends: R (>= 3.3.0)
Imports: sp, raster
Suggests: foreign, maptools, rgdal, sf, spDataLarge (>= 0.3.0), spdep,
        spatialreg
License: CC0
RoxygenNote: 7.0.2
LazyData: true
URL: https://nowosad.github.io/spData/
BugReports: https://github.com/Nowosad/spData/issues
Additional_repositories: https://nowosad.github.io/drat
NeedsCompilation: no
Packaged: 2020-02-11 09:46:52 UTC; jn
Author: Roger Bivand [aut] (<https://orcid.org/0000-0003-2392-6140>),
  Jakub Nowosad [aut, cre] (<https://orcid.org/0000-0002-1057-3721>),
  Robin Lovelace [aut] (<https://orcid.org/0000-0001-5679-6536>),
  Mark Monmonier [ctb] (author of the state.vbm dataset),
  Greg Snow [ctb] (author of the state.vbm dataset)
Maintainer: Jakub Nowosad <nowosad.jakub@gmail.com>
Repository: CRAN
Date/Publication: 2020-02-11 13:00:02 UTC
