#' @name jenks71
#' @aliases jenks71
#' @title Illinois 1959 county gross farm product value per acre
#'
#' @description Classic data set for the choice of class intervals for choropleth maps.
#' 
#' @format A data frame with 102 observations on the following 2 variables.
#' \itemize{
#'         \item{\code{jenks71}} {a numeric vector: Per acre value of gross farm products in dollars by county for Illinois in #' 1959}
#'         \item{\code{area}} {a numeric vector: county area in square miles}
#' }
#' 
#' @source Jenks, G. F., Caspall, F. C., 1971. "Error on choroplethic maps: definition, measurement, reduction". Annals, Association of American Geographers, 61 (2), 217--244
#' @docType data
#' @keywords datasets misc
#' 
#' @examples 
#' data(jenks71)
#' jenks71
"jenks71"
