#' @name grain.tif
#' @title Artificial raster dataset representing grain sizes
#' @description The ratified raster dataset represents grain sizes with the
#'   three classes clay, silt and sand, and WGS84 as a coordinate reference
#'   system.
#' @docType data
#' @keywords datasets raster
#' 
#' @examples 
#' system.file("raster/grain.tif", package = "spData")
NULL
