#' @name elev.tif
#' @title Artificial elevation raster data set
#'
#' @description The raster data represents elevation in meters and uses WGS84 as
#'   a coordinate reference system.
#' @docType data
#' @keywords datasets raster
#' 
#' @examples 
#' system.file("raster/elev.tif", package = "spData")
NULL

